==> xoops-2.0.4-lang-ja-eucjp.zip: xoops-2.0.4-lang-ja-eucjp/html/language/japanese/user.php <==
<?php
//%%%%%%		File Name user.php 		%%%%%
define('_US_NOTREGISTERED','<a href=register.php>Ͽ</a>ޤ󤫡');
define('_US_LOSTPASSWORD','ѥɤʶޤ');
define('_US_NOPROBLEM','ۤʤޤϤʤϿ˻Ѥ᡼륢ɥ쥹Ϥܥ򥯥åƤ ѥɼѤΥ󥯤ܤ줿᡼뤬ʤϿ᡼륢ɥ쥹ޤ');
define('_US_YOUREMAIL','Ͽ᡼륢ɥ쥹');
define('_US_SENDPASSWORD','');
define('_US_LOGGEDOUT','Ȥޤ');
define('_US_THANKYOUFORVISIT','ȤѤ꤬Ȥޤ');
define('_US_INCORRECTLOGIN','󤬴ְäƤޤ');
define('_US_LOGGINGU','%s󡢤褦Ǥ');

// 2001-11-17 ADD
define('_US_NOACTTPADM','򤵤줿桼Ϥޤ¸ߤʤǧλƤޤ<br />ܺ٤ˤĤƤϥȴԤˤ礻');
define('_US_ACTKEYNOT','ǧְäƤޤ');
define('_US_ACONTACT','򤵤줿Ȥϴ˾ǧλƤޤ');
define('_US_ACTLOGIN','ȤǧޤϿκݤ˵ѥɤѤƥ󤷤Ƥ');
define('_US_NOPERMISS','Υ桼ѹ뤳ȤϤǤޤ');
define('_US_SURETODEL','桼Ȥ˺ƤɤǤ');
define('_US_REMOVEINFO','Ȥ硢ƤΥ桼󤬼ޤ');
define('_US_BEENDELED','Ȥޤ');
//

//%%%%%%		File Name register.php 		%%%%%
define('_US_USERREG','桼Ͽ');
define('_US_NICKNAME','桼̾');
define('_US_EMAIL','᡼륢ɥ쥹');
define('_US_ALLOWVIEWEMAIL','Υ᡼륢ɥ쥹');
define('_US_WEBSITE','ۡڡ');
define('_US_TIMEZONE','ॾ');
define('_US_AVATAR','Х');
define('_US_VERIFYPASS','ѥɳǧ');
define('_US_SUBMIT','');
define('_US_USERNAME','桼̾');
define('_US_FINISH','');
define('_US_REGISTERNG','ϿǤޤǤ');
define('_US_MAILOK','Ȥοʤɤ<br />᡼Ǽ');

define('_US_INVALIDMAIL','ʥ᡼륢ɥ쥹Ǥ');
define('_US_EMAILNOSPACES','᡼륢ɥ쥹˶ޤʤǤ');
define('_US_INVALIDNICKNAME','ʥ桼̾Ǥ');
define('_US_NICKNAMETOOLONG','桼̾ĹޤȾ %s ʸ˼Ƥ');
define('_US_NICKNAMETOOSHORT','桼̾ûޤȾ %s ʸʾˤƤ');
define('_US_NAMERESERVED','Υ桼̾ϻѤǤޤ');
define('_US_NICKNAMENOSPACES','桼̾˶ޤʤǤ');
define('_US_NICKNAMETAKEN','Υ桼̾ϴ˻ѤƤޤ');
define('_US_EMAILTAKEN','Υ᡼륢ɥ쥹ϴ˻ѤƤޤ');
define('_US_ENTERPWD','ѥɤƤ');
define('_US_SORRYNOTFOUND','桼󤬸ĤޤǤ');

define('_US_DISCLAIMER','');
define('_US_IAGREE','Ͼ嵭Ʊդޤ');
define('_US_UNEEDAGREE', 'ޤ󤬡Ͽ뤿ˤջˤƱդɬפޤ');
define('_US_NOREGISTER','ޤ󤬡ߤΥȤǤϿ桼ϿդԤäƤޤ');

// %s is username. This is a subject for email
define('_US_USERKEYFOR','%sξǧǤ');

define('_US_YOURREGISTERED','Ͽλޤܤ줿᡼Ͽ᡼륢ɥ쥹˾ǧޤ᡼λؼ˽ǧλƤ');
define('_US_YOURREGMAILNG','Ͽλޤ顼ˤ꾵ǧܤ줿᡼뤳ȤǤޤǤѿޤ󤬡ȴԤޤǤ䤤碌');
define('_US_YOURREGISTERED2','ϿλޤȴԤȤǧޤǤԤǧλˤϥ᡼ˤƤΤ餻ޤ');

// %s is your site name
define('_US_NEWUSERREGAT','Ͽ桼%s');
// %s is a username
define('_US_HASJUSTREG','Ͽ桼ޤ桼̾%s');

// %s is your site name
define('_US_NEWPWDREQ','ѥɤΥꥯȡ%s');
define('_US_YOURACCOUNT', '%sǤΥ桼');

define('_US_MAILPWDNG','mail_password: 桼ι˼ԤޤǤȴԤޤǤ礻');

// %s is a username
define('_US_PWDMAILED','%s󰸤˥ѥɤޤ');
define('_US_CONFMAIL','ѥɼѥ󥯤ܤ줿᡼%s󰸤ޤ');
define('_US_ACTVMAILNG', '%sؤΥ᡼˼Ԥޤ');
define('_US_ACTVMAILOK', '%sإ᡼ޤ');

//%%%%%%		File Name userinfo.php 		%%%%%
define('_US_SELECTNG','桼򤵤Ƥޤ');
define('_US_PM','PM');
define('_US_ICQ','ICQ');
define('_US_AIM','AIM');
define('_US_YIM','YIM');
define('_US_MSNM','MSNM');
define('_US_LOCATION','ｻ');
define('_US_OCCUPATION','');
define('_US_INTEREST','̣');
define('_US_SIGNATURE','̾');
define('_US_EXTRAINFO','¾');
define('_US_EDITPROFILE','ץեԽ');
define('_US_LOGOUT','');
define('_US_INBOX','Ȣ');
define('_US_MEMBERSINCE','Ͽ');
define('_US_RANK','');
define('_US_POSTS','ƿ');
define('_US_LASTLOGIN','ǽ');
define('_US_ALLABOUT','%sδܾ');
define('_US_STATISTICS','׾');
define('_US_MYINFO','Ŀ;');//My Info');
define('_US_BASICINFO','ܾ');
define('_US_MOREABOUT','Ŀ;ܺ');//More About Me');
define('_US_SHOWALL','٤ɽ');


//%%%%%%		File Name edituser.php 		%%%%%
define('_US_PROFILE','ץե');
define('_US_REALNAME','̾');
define('_US_SHOWSIG','Ƥ˽̾ɬɲä');
define('_US_CDISPLAYMODE','ɽ⡼');
define('_US_CSORTORDER','Ȥ¤ӽ');
define('_US_PASSWORD','ѥ');
define('_US_TYPEPASSTWICE','ʥѥɤѹΤߵƤ');
define('_US_SAVECHANGES','ѹ¸');
define('_US_NOEDITRIGHT','Υ桼ѹ븢¤ޤ');
define('_US_PASSNOTSAME','ѥɤޤƱѥɤϤƤ');
define('_US_PWDTOOSHORT','ѥɤȾ<b>%s</b>ʸʾˤƤ');
define('_US_PROFUPDATED','ץե򹹿ޤ');
define('_US_USECOOKIE','桼̾ǯ֥å¸');
define('_US_NO','');
define('_US_DELACCOUNT','Ȥ');
define('_US_MYAVATAR', 'åץɺѥХ');
define('_US_UPLOADMYAVATAR', 'Х򥢥åץɤ');
define('_US_MAXPIXEL','ԥ');
define('_US_MAXIMGSZ','ե륵');
define('_US_SELFILE','ե');
define('_US_OLDDELETED','ŤХϾ񤭤ޤ');
define('_US_CHOOSEAVT', 'Х򤷤Ƥ');
define('_US_PRESSLOGIN', 'ܥ򥯥åƥ󤷤Ƥ');
?>

==> xoops-2.0.5-lang-ja-eucjp.zip: xoops-2.0.5-lang-ja-eucjp/html/language/japanese/user.php <==
<?php
//%%%%%%		File Name user.php 		%%%%%
define('_US_NOTREGISTERED','<a href=register.php>Ͽ</a>ޤ󤫡');
define('_US_LOSTPASSWORD','ѥɤʶޤ');
define('_US_NOPROBLEM','ۤʤޤϤʤϿ˻Ѥ᡼륢ɥ쥹Ϥܥ򥯥åƤ ѥɼѤΥ󥯤ܤ줿᡼뤬ʤϿ᡼륢ɥ쥹ޤ');
define('_US_YOUREMAIL','Ͽ᡼륢ɥ쥹');
define('_US_SENDPASSWORD','');
define('_US_LOGGEDOUT','Ȥޤ');
define('_US_THANKYOUFORVISIT','ȤѤ꤬Ȥޤ');
define('_US_INCORRECTLOGIN','󤬴ְäƤޤ');
define('_US_LOGGINGU','%s󡢤褦Ǥ');

// 2001-11-17 ADD
define('_US_NOACTTPADM','򤵤줿桼Ϥޤ¸ߤʤǧλƤޤ<br />ܺ٤ˤĤƤϥȴԤˤ礻');
define('_US_ACTKEYNOT','ǧְäƤޤ');
define('_US_ACONTACT','򤵤줿Ȥϴ˾ǧλƤޤ');
define('_US_ACTLOGIN','ȤǧޤϿκݤ˵ѥɤѤƥ󤷤Ƥ');
define('_US_NOPERMISS','Υ桼ѹ뤳ȤϤǤޤ');
define('_US_SURETODEL','桼Ȥ˺ƤɤǤ');
define('_US_REMOVEINFO','Ȥ硢ƤΥ桼󤬼ޤ');
define('_US_BEENDELED','Ȥޤ');
//

//%%%%%%		File Name register.php 		%%%%%
define('_US_USERREG','桼Ͽ');
define('_US_NICKNAME','桼̾');
define('_US_EMAIL','᡼륢ɥ쥹');
define('_US_ALLOWVIEWEMAIL','Υ᡼륢ɥ쥹');
define('_US_WEBSITE','ۡڡ');
define('_US_TIMEZONE','ॾ');
define('_US_AVATAR','Х');
define('_US_VERIFYPASS','ѥɳǧ');
define('_US_SUBMIT','');
define('_US_USERNAME','桼̾');
define('_US_FINISH','');
define('_US_REGISTERNG','ϿǤޤǤ');
define('_US_MAILOK','Ȥοʤɤ᡼Ǽ');

define('_US_INVALIDMAIL','ʥ᡼륢ɥ쥹Ǥ');
define('_US_EMAILNOSPACES','᡼륢ɥ쥹˶ޤʤǤ');
define('_US_INVALIDNICKNAME','ʥ桼̾Ǥ');
define('_US_NICKNAMETOOLONG','桼̾ĹޤȾ %s ʸ˼Ƥ');
define('_US_NICKNAMETOOSHORT','桼̾ûޤȾ %s ʸʾˤƤ');
define('_US_NAMERESERVED','Υ桼̾ϻѤǤޤ');
define('_US_NICKNAMENOSPACES','桼̾˶ޤʤǤ');
define('_US_NICKNAMETAKEN','Υ桼̾ϴ˻ѤƤޤ');
define('_US_EMAILTAKEN','Υ᡼륢ɥ쥹ϴ˻ѤƤޤ');
define('_US_ENTERPWD','ѥɤƤ');
define('_US_SORRYNOTFOUND','桼󤬸ĤޤǤ');

define('_US_DISCLAIMER','');
define('_US_IAGREE','Ͼ嵭Ʊդޤ');
define('_US_UNEEDAGREE', 'ޤ󤬡Ͽ뤿ˤջˤƱդɬפޤ');
define('_US_NOREGISTER','ޤ󤬡ߤΥȤǤϿ桼ϿդԤäƤޤ');

// %s is username. This is a subject for email
define('_US_USERKEYFOR','%sξǧǤ');

define('_US_YOURREGISTERED','Ͽλޤܤ줿᡼Ͽ᡼륢ɥ쥹˾ǧޤ᡼λؼ˽ǧλƤ');
define('_US_YOURREGMAILNG','Ͽλޤ顼ˤ꾵ǧܤ줿᡼뤳ȤǤޤǤѿޤ󤬡ȴԤޤǤ䤤碌');
define('_US_YOURREGISTERED2','ϿλޤȴԤȤǧޤǤԤǧλˤϥ᡼ˤƤΤ餻ޤ');

// %s is your site name
define('_US_NEWUSERREGAT','Ͽ桼%s');
// %s is a username
define('_US_HASJUSTREG','Ͽ桼ޤ桼̾%s');

// %s is your site name
define('_US_NEWPWDREQ','ѥɤΥꥯȡ%s');
define('_US_YOURACCOUNT', '%sǤΥ桼');

define('_US_MAILPWDNG','mail_password: 桼ι˼ԤޤǤȴԤޤǤ礻');

// %s is a username
define('_US_PWDMAILED','%s󰸤˥ѥɤޤ');
define('_US_CONFMAIL','ѥɼѥ󥯤ܤ줿᡼%s󰸤ޤ');
define('_US_ACTVMAILNG', '%sؤΥ᡼˼Ԥޤ');
define('_US_ACTVMAILOK', '%sإ᡼ޤ');

//%%%%%%		File Name userinfo.php 		%%%%%
define('_US_SELECTNG','桼򤵤Ƥޤ');
define('_US_PM','PM');
define('_US_ICQ','ICQ');
define('_US_AIM','AIM');
define('_US_YIM','YIM');
define('_US_MSNM','MSNM');
define('_US_LOCATION','ｻ');
define('_US_OCCUPATION','');
define('_US_INTEREST','̣');
define('_US_SIGNATURE','̾');
define('_US_EXTRAINFO','¾');
define('_US_EDITPROFILE','ץեԽ');
define('_US_LOGOUT','');
define('_US_INBOX','Ȣ');
define('_US_MEMBERSINCE','Ͽ');
define('_US_RANK','');
define('_US_POSTS','ƿ');
define('_US_LASTLOGIN','ǽ');
define('_US_ALLABOUT','%sδܾ');
define('_US_STATISTICS','׾');
define('_US_MYINFO','Ŀ;');//My Info');
define('_US_BASICINFO','ܾ');
define('_US_MOREABOUT','Ŀ;ܺ');//More About Me');
define('_US_SHOWALL','٤ɽ');


//%%%%%%		File Name edituser.php 		%%%%%
define('_US_PROFILE','ץե');
define('_US_REALNAME','̾');
define('_US_SHOWSIG','Ƥ˽̾ɬɲä');
define('_US_CDISPLAYMODE','ɽ⡼');
define('_US_CSORTORDER','Ȥ¤ӽ');
define('_US_PASSWORD','ѥ');
define('_US_TYPEPASSTWICE','ʥѥɤѹΤߵƤ');
define('_US_SAVECHANGES','ѹ¸');
define('_US_NOEDITRIGHT','Υ桼ѹ븢¤ޤ');
define('_US_PASSNOTSAME','ѥɤޤƱѥɤϤƤ');
define('_US_PWDTOOSHORT','ѥɤȾ<b>%s</b>ʸʾˤƤ');
define('_US_PROFUPDATED','ץե򹹿ޤ');
define('_US_USECOOKIE','桼̾ǯ֥å¸');
define('_US_NO','');
define('_US_DELACCOUNT','Ȥ');
define('_US_MYAVATAR', 'åץɺѥХ');
define('_US_UPLOADMYAVATAR', 'Х򥢥åץɤ');
define('_US_MAXPIXEL','ԥ');
define('_US_MAXIMGSZ','ե륵');
define('_US_SELFILE','ե');
define('_US_OLDDELETED','ŤХϾ񤭤ޤ');
define('_US_CHOOSEAVT', 'Х򤷤Ƥ');
define('_US_PRESSLOGIN', 'ܥ򥯥åƥ󤷤Ƥ');
?>
